@@ -150,7 +150,7 @@ def our_float_handler(x):
 
 def PrettyPolynomialTuple(numCoefficients, denCoefficients):
     """
-    Strings for numerator and denominator of the a hilbert series.
+    Strings for numerator and denominator of the a Hilbert series.
 
     Parameters
     ----------
@@ -236,7 +236,7 @@ def PrettyPolynomialTuple(numCoefficients, denCoefficients):
 
 def PrintPrettyHilbertSeries(numCoefficients, denCoefficients):
     """
-    Make a pretty hilbert series string
+    Make a pretty Hilbert series string
 
     Parameters
     ----------
@@ -385,6 +385,9 @@ class Cone:
     def SetFaceCodimBound(self, bound=-1):
         return PyNormaliz_cpp.NmzSetFaceCodimBound(self.cone, bound)
 
+    def SetModularGrading(self, mod_gr=-1):
+        return PyNormaliz_cpp.NmzSetModularGrading(self.cone, mod_gr)
+
     def SetGBDegreeBound(self, bound=-1):
         return PyNormaliz_cpp.NmzSetGBDegreeBound(self.cone, bound)
 
